Struct datafrog::Iteration [−][src]
pub struct Iteration { /* fields omitted */ }An iterative context for recursive evaluation.
An Iteration tracks monotonic variables, and monitors their progress.
It can inform the user if they have ceased changing, at which point the
computation should be done.
Methods
impl Iteration[src]
impl Iterationpub fn new() -> Self[src]
pub fn new() -> SelfCreate a new iterative context.
pub fn changed(&mut self) -> bool[src]
pub fn changed(&mut self) -> boolReports whether any of the monitored variables have changed since the most recent call.
pub fn variable<Tuple: Ord + 'static>(&mut self, name: &str) -> Variable<Tuple>[src]
pub fn variable<Tuple: Ord + 'static>(&mut self, name: &str) -> Variable<Tuple>Creates a new named variable associated with the iterative context.
pub fn variable_indistinct<Tuple: Ord + 'static>(
&mut self,
name: &str
) -> Variable<Tuple>[src]
pub fn variable_indistinct<Tuple: Ord + 'static>(
&mut self,
name: &str
) -> Variable<Tuple>Creates a new named variable associated with the iterative context.
This variable will not be maintained distinctly, and may advertise tuples as recent multiple times (perhaps unboundedly many times).